Page 30 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 30

Home

    could pillage the goods and shed the blood of their
    adversaries with impunity.

    Peaceful fraternity was thus turned into a wild lust for
    conquest as the Karmathites became a band of robbers,
    pillaging and massacring throughout all the surrounding
    districts. Nesta Webster quotes von Kammer as saying:

    For a whole century the pernicious doctrines of
    Karmath raged with fire and sword in the very bosom of
    Islamism, until the wide spread conflagration was
    extinguished in blood.*

    25

    Secret Societies